==> open-vm-tools-6:12.5.2-2-x86_64.pkg.tar.zst: usr/share/doc/open-vm-tools/api/html/plugin_8h.js <==
var plugin_8h =
[
    [ "TOOLS_CORE_EVENTS_TOOLS_NEED_REBOOT", "group__vmtools__plugins.html#ga0d23ba34793d67e8381b5ecf486db349", null ],
    [ "TOOLS_CORE_EVENTS_TOOLS_NEW_VERSION", "group__vmtools__plugins.html#ga7edbc0477b6eb0960b8a70da4e0bcc9e", null ],
    [ "TOOLS_CORE_PROP_CTX", "group__vmtools__plugins.html#ga450171ca281fd371eb424719dc037722", null ],
    [ "TOOLS_CORE_SIG_CAPABILITIES", "group__vmtools__plugins.html#gafceeec827816178fbc61e805cbe5c792", null ],
    [ "TOOLS_CORE_SIG_CONF_RELOAD", "group__vmtools__plugins.html#ga7bfffd963f786f08049fe38511d47af2", null ],
    [ "TOOLS_CORE_SIG_DUMP_STATE", "group__vmtools__plugins.html#ga9a38cacea4dcea975cac21e3ab530ccb", null ],
    [ "TOOLS_CORE_SIG_NO_RPC", "group__vmtools__plugins.html#ga6ff9dd452029f442a272c09adbe9215e", null ],
    [ "TOOLS_CORE_SIG_RESET", "group__vmtools__plugins.html#gad19d1d9e78cf796ba25504eaad2d2664", null ],
    [ "TOOLS_CORE_SIG_SET_OPTION", "group__vmtools__plugins.html#ga2fa6cca2e2cde6109bfc11ed2e9eb760", null ],
    [ "TOOLS_CORE_SIG_SHUTDOWN", "group__vmtools__plugins.html#ga4d5500a712a7da98ad1e2edec95adbfa", null ],
    [ "TOOLS_IS_MAIN_SERVICE", "group__vmtools__plugins.html#ga7679bde10a493dcd1a84e73b6fa2c262", null ],
    [ "TOOLS_IS_USER_SERVICE", "group__vmtools__plugins.html#ga5bcb18fe90325ec85d241e82f166389f", null ],
    [ "TOOLS_MODULE_EXPORT", "group__vmtools__plugins.html#ga1960f65a5ba3452d950e0be70dc17fa1", null ],
    [ "VMTOOLSAPP_ATTACH_SOURCE", "group__vmtools__plugins.html#gac1786fe2219c3028d8f518c3eba82c99", null ],
    [ "VMTOOLSAPP_ERROR", "group__vmtools__plugins.html#gae845433f58220cfe3f0e56a51a410c0e", null ],
    [ "RegisterServiceProperty", "group__vmtools__plugins.html#ga8903254ca4928a36b43aee7ecd791e67", null ],
    [ "ToolsAppCapability", "group__vmtools__plugins.html#ga6b32067f979d185450030584c29070cf", null ],
    [ "ToolsAppCtx", "group__vmtools__plugins.html#ga039699aca0ff2123fbf8282093f94d65", null ],
    [ "ToolsAppProvider", "group__vmtools__plugins.html#gaae918e9a1b49a16bee5af2512c34f0bb", null ],
    [ "ToolsAppReg", "group__vmtools__plugins.html#ga7b8f660d48bcd005ea8b99a143c20b01", null ],
    [ "ToolsPluginData", "group__vmtools__plugins.html#gad4eab2c115c5486a14440c61c011e537", null ],
    [ "ToolsPluginOnLoad", "group__vmtools__plugins.html#ga802b027f0c1e9dbb572ad1294acab26c", null ],
    [ "ToolsPluginSignalCb", "group__vmtools__plugins.html#ga4a658da538bce5c5bf84005436fa6ae3", null ],
    [ "ToolsServiceProperty", "group__vmtools__plugins.html#gac26226450521ac963c1cb2a41f55e071", null ],
    [ "ToolsAppType", "group__vmtools__plugins.html#gaa58c4987a21e2bdbb4a7a6e28eb861a6", [
      [ "TOOLS_APP_GUESTRPC", "group__vmtools__plugins.html#ggaa58c4987a21e2bdbb4a7a6e28eb861a6a2192ecd9b4c16376a1e8536f4119de4b", null ],
      [ "TOOLS_APP_SIGNALS", "group__vmtools__plugins.html#ggaa58c4987a21e2bdbb4a7a6e28eb861a6a79ac5216bff892349d250d16e61d5f87", null ],
      [ "TOOLS_APP_PROVIDER", "group__vmtools__plugins.html#ggaa58c4987a21e2bdbb4a7a6e28eb861a6a8121f83d027f9b28f7b8a0e4dab46b36", null ],
      [ "TOOLS_SVC_PROPERTY", "group__vmtools__plugins.html#ggaa58c4987a21e2bdbb4a7a6e28eb861a6a80c5c900fc3aaf4100b8d12010a315e7", null ]
    ] ],
    [ "ToolsCapabilityType", "group__vmtools__plugins.html#ga30463f9d97822958018ae83e28321fa9", [
      [ "TOOLS_CAP_OLD", "group__vmtools__plugins.html#gga30463f9d97822958018ae83e28321fa9a1bcc06a613a92134f2e569f220e4ee0f", null ],
      [ "TOOLS_CAP_OLD_NOVAL", "group__vmtools__plugins.html#gga30463f9d97822958018ae83e28321fa9a41fbde5c7b3205928b023bd934afc89f", null ],
      [ "TOOLS_CAP_NEW", "group__vmtools__plugins.html#gga30463f9d97822958018ae83e28321fa9ade59c39b9a7eb16bd64fe8278360890d", null ]
    ] ],
    [ "ToolsCoreAPI", "group__vmtools__plugins.html#gab74b3a7ffdbb9972f4a104098529ef64", [
      [ "TOOLS_CORE_API_V1", "group__vmtools__plugins.html#ggab74b3a7ffdbb9972f4a104098529ef64a1ff9fcfa712bb6e9cb2173ecf145f4c9", null ]
    ] ]
];

==> open-vm-tools-6:13.0.10-1-x86_64.pkg.tar.zst: usr/share/doc/open-vm-tools/api/html/plugin_8h.js <==
var plugin_8h =
[
    [ "TOOLS_CORE_EVENTS_TOOLS_NEED_REBOOT", "group__vmtools__plugins.html#ga0d23ba34793d67e8381b5ecf486db349", null ],
    [ "TOOLS_CORE_EVENTS_TOOLS_NEW_VERSION", "group__vmtools__plugins.html#ga7edbc0477b6eb0960b8a70da4e0bcc9e", null ],
    [ "TOOLS_CORE_PROP_CTX", "group__vmtools__plugins.html#ga450171ca281fd371eb424719dc037722", null ],
    [ "TOOLS_CORE_SIG_CAPABILITIES", "group__vmtools__plugins.html#gafceeec827816178fbc61e805cbe5c792", null ],
    [ "TOOLS_CORE_SIG_CONF_RELOAD", "group__vmtools__plugins.html#ga7bfffd963f786f08049fe38511d47af2", null ],
    [ "TOOLS_CORE_SIG_DUMP_STATE", "group__vmtools__plugins.html#ga9a38cacea4dcea975cac21e3ab530ccb", null ],
    [ "TOOLS_CORE_SIG_NO_RPC", "group__vmtools__plugins.html#ga6ff9dd452029f442a272c09adbe9215e", null ],
    [ "TOOLS_CORE_SIG_PRE_SHUTDOWN", "group__vmtools__plugins.html#ga4bbcebbfdaf7bf55375685074795efe8", null ],
    [ "TOOLS_CORE_SIG_RESET", "group__vmtools__plugins.html#gad19d1d9e78cf796ba25504eaad2d2664", null ],
    [ "TOOLS_CORE_SIG_SET_OPTION", "group__vmtools__plugins.html#ga2fa6cca2e2cde6109bfc11ed2e9eb760", null ],
    [ "TOOLS_CORE_SIG_SHUTDOWN", "group__vmtools__plugins.html#ga4d5500a712a7da98ad1e2edec95adbfa", null ],
    [ "TOOLS_IS_MAIN_SERVICE", "group__vmtools__plugins.html#ga7679bde10a493dcd1a84e73b6fa2c262", null ],
    [ "TOOLS_IS_USER_SERVICE", "group__vmtools__plugins.html#ga5bcb18fe90325ec85d241e82f166389f", null ],
    [ "TOOLS_MODULE_EXPORT", "group__vmtools__plugins.html#ga1960f65a5ba3452d950e0be70dc17fa1", null ],
    [ "VMTOOLSAPP_ATTACH_SOURCE", "group__vmtools__plugins.html#gac1786fe2219c3028d8f518c3eba82c99", null ],
    [ "VMTOOLSAPP_ERROR", "group__vmtools__plugins.html#gae845433f58220cfe3f0e56a51a410c0e", null ],
    [ "RegisterServiceProperty", "group__vmtools__plugins.html#ga8903254ca4928a36b43aee7ecd791e67", null ],
    [ "ToolsAppCapability", "group__vmtools__plugins.html#ga6b32067f979d185450030584c29070cf", null ],
    [ "ToolsAppCtx", "group__vmtools__plugins.html#ga039699aca0ff2123fbf8282093f94d65", null ],
    [ "ToolsAppProvider", "group__vmtools__plugins.html#gaae918e9a1b49a16bee5af2512c34f0bb", null ],
    [ "ToolsAppReg", "group__vmtools__plugins.html#ga7b8f660d48bcd005ea8b99a143c20b01", null ],
    [ "ToolsPluginData", "group__vmtools__plugins.html#gad4eab2c115c5486a14440c61c011e537", null ],
    [ "ToolsPluginOnLoad", "group__vmtools__plugins.html#ga802b027f0c1e9dbb572ad1294acab26c", null ],
    [ "ToolsPluginSignalCb", "group__vmtools__plugins.html#ga4a658da538bce5c5bf84005436fa6ae3", null ],
    [ "ToolsServiceProperty", "group__vmtools__plugins.html#gac26226450521ac963c1cb2a41f55e071", null ],
    [ "ToolsAppType", "group__vmtools__plugins.html#gaa58c4987a21e2bdbb4a7a6e28eb861a6", [
      [ "TOOLS_APP_GUESTRPC", "group__vmtools__plugins.html#ggaa58c4987a21e2bdbb4a7a6e28eb861a6a2192ecd9b4c16376a1e8536f4119de4b", null ],
      [ "TOOLS_APP_SIGNALS", "group__vmtools__plugins.html#ggaa58c4987a21e2bdbb4a7a6e28eb861a6a79ac5216bff892349d250d16e61d5f87", null ],
      [ "TOOLS_APP_PROVIDER", "group__vmtools__plugins.html#ggaa58c4987a21e2bdbb4a7a6e28eb861a6a8121f83d027f9b28f7b8a0e4dab46b36", null ],
      [ "TOOLS_SVC_PROPERTY", "group__vmtools__plugins.html#ggaa58c4987a21e2bdbb4a7a6e28eb861a6a80c5c900fc3aaf4100b8d12010a315e7", null ]
    ] ],
    [ "ToolsCapabilityType", "group__vmtools__plugins.html#ga30463f9d97822958018ae83e28321fa9", null ],
    [ "ToolsCoreAPI", "group__vmtools__plugins.html#gab74b3a7ffdbb9972f4a104098529ef64", null ]
];
